@@ -1,8 +1,27 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-"""`fdsnavail` lets the user interact with the new availability web service deployed at many data centres.
-There are three modes of operation: `query`, `scan`, and `compare`.
+"""fdsnavail
+
+This program is free software: you can redistribute it and/or modify
+it under the terms of the GNU Lesser General Public License as published
+by the Free Software Foundation, either version 3 of the License, or
+any later version.
+
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU Lesser General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with this program.  If not, see <http://www.gnu.org/licenses/>.
+
+   :Copyright:
+       2019-2025 GFZ Helmholtz Centre for Geosciences
+   :License:
+       LGPLv3 GNU Lesser General Public License v. 3 (29 June 2007, or later)
+   :Platform:
+       Linux
 """
 
 import sys
